@@ -2,6 +2,8 @@ import os
 import json
 import sys
 import time
+import ntpath
+from decimal import Decimal
 
 from .utils import Utils, DockerError, S3Error
 from threading import Timer
@@ -9,6 +11,7 @@ from threading import Timer
 STATUS_RUNNING = 'RUNNING'
 STATUS_ERROR_ETL_BLOCKED = 'ERROR_ETL_BLOCKED'
 STATUS_ERROR = 'ERROR'
+SCANNER_FINDSECBUGS = 'findsecbugs'
 
 class ETLError(Exception):
     pass
@@ -16,7 +19,7 @@ class ETLError(Exception):
 class ScanRunner(object):
     aws_config = None
     scan_data_items = None
-    api_id = None
+    org_id = None
     app_id = None
     app_number_id = None
     build_dir = None
@@ -26,6 +29,8 @@ class ScanRunner(object):
     ignore_limit = False
     file_count = 0
     line_count = 0
+    size_100_MB = 100*1024*1024
+    environment_variables = None
 
     @classmethod
     def get_scan_data(cls, req):
@@ -59,7 +64,7 @@ class ScanRunner(object):
     def _create_etl_request(cls):
         req = {
             'appId': cls.app_id,
-            'apiId': cls.api_id,
+            'apiId': cls.org_id,
             'scanDataItems': cls.scan_data_items
         }
 
@@ -184,14 +189,40 @@ class ScanRunner(object):
                 Utils.etl_waiting_countdown()
                 scan_data['status'] = STATUS_RUNNING
 
+            # for findsecbugs, throw error if no MAVEN_REPO_PATH or GRADLE_CACHE_PATH specified
+            if scan_data['scanner'] == SCANNER_FINDSECBUGS and not ('maven_repo_path' in cls.environment_variables and 'gradle_cache_path' in cls.environment_variables):
+                scan_data['status'] = STATUS_ERROR
+                scan_data['errorMessage'] = 'Error: unable to find a suitable classpath directory. Try running a build.'
+                print('Failed to run ' + scan_data['scanner'] + ' on your project. ' + scan_data['errorMessage'])
+                cls.do_etl()
+                return
+
             start_time = Utils.get_timestamp()
             print(('Launching scanner ' + scan_data['scanner']).ljust(50, ' '))
+            # check file limit per scanner
+            # todo: check file limit based on the per language count of cloc result?
+            if not cls.ignore_limit and scan_data['fileLimit'] != 0 and cls.file_count > scan_data['fileLimit']:
+                scan_data['status'] = STATUS_ERROR
+                scan_data['errorMessage'] = 'Too many files: ' + str(cls.file_count) + '. Limit of ' + str(scan_data['fileLimit']) + '.'
+                print('sken.ai is currently unable to run ' + scan_data['scanner'] + ' on your project, ' + scan_data['errorMessage'])
+                cls.do_etl()
+                return
+
             output_file = cls.run_docker(scan_data)
             #output_file = cls.build_dir + scan_data['outputFile']
             # upload file
             file_empty = False
+            file_size = 0
             if os.path.exists(output_file):
-                file_empty = os.path.getsize(output_file) <= 0
+                file_size = os.path.getsize(output_file)
+                file_empty = (file_size <= 0)
+
+                if file_size > cls.size_100_MB:
+                    scan_data['status'] = STATUS_ERROR
+                    scan_data['errorMessage'] = 'Output file ' + ntpath.basename(output_file) + ' too big: ' + str(Decimal(file_size/(1024*1024)).quantize(Decimal('1.00'))) + ' MB.'
+                    print('sken.ai is currently unable to run ' + scan_data['scanner'] + ' on your project, ' + scan_data['errorMessage'])
+                    cls.do_etl()
+                    return
             else:
                 file_empty = True
             
@@ -253,11 +284,12 @@ class ScanRunner(object):
     def run(cls, req):
         # get initial scan data items
         cls.app_id = req['appid']
-        cls.api_id = req['apiid']
+        cls.org_id = req['orgid']
         cls.build_dir = req['buildDir']
         cls.ignore_limit = req['ignoreLimit']
         cls.file_count = req['files']
         cls.line_count = req['linesOfCode']
+        cls.environment_variables = req['environment_variables']
         Utils.create_skenoutput_folder(cls.build_dir + 'skenoutput')
 
         cls.get_scan_data(req)
