@@ -28,7 +28,7 @@ def get_build_dir(command_args):
 def parse_command_line_params():
     parser = argparse.ArgumentParser(description='Sken Runner.')
 
-    parser.add_argument('--api_id', metavar='API Id', help='API Id.')
+    parser.add_argument('--org_id', metavar='API Id', help='Organization Id.')
     parser.add_argument('--app_id', metavar='Application Id', help='Application Id.')
     parser.add_argument('--scanner', metavar='Scanner', nargs='+', choices=SCANNERS, help='support scanners: ' + ','.join(SCANNERS))
     parser.add_argument('--lang', metavar='Language', nargs='+', choices=LANGUAGES, help='support languages: ' + ','.join(LANGUAGES))
@@ -45,9 +45,10 @@ def parse_command_line_params():
     parser.add_argument('--var_findsecgubs_exclude_path', metavar='Exclude path of Findsecbugs scanner', help='Exclude path of Findsecbugs scanner.')
     parser.add_argument('--var_nodejsscan_exclude_path', metavar='Exclude path of NodeJsScan scanner', help='Exclude path of NodeJsScan scanner.')
     parser.add_argument('--var_maven_repo_path', metavar='Maven repo path', help='Maven repo path.')
-    parser.add_argument('--var_gradle_repo_path', metavar='Gradle repo path', help='Gradle repo path.')
+    parser.add_argument('--var_gradle_cache_path', metavar='Gradle cache path', help='Gradle cache path.')
     parser.add_argument('--version', action='store_true', help='View skencli Version.')
     parser.add_argument('--ignore-limit', action='store_true', help='Ignore file and loc limits.')
+    parser.add_argument('--test', action='store_true', help='Connects to the test server.')
 
     command_args = parser.parse_args()
 
@@ -82,20 +83,30 @@ def parse_command_line_params():
 
         command_line_params['language'] = Utils.remove_duplicated_items_list(languages)
 
+    if command_args.test:
+        Utils.set_test_mode()
+
     return command_line_params, command_args
 
 def get_app_ids(command_args, yaml_config):
-    api_id = ''
+    org_id = ''
     app_id = ''
+    yaml_file = 'sken.yaml'
 
-    if 'apiid' in yaml_config and yaml_config['apiid'] is not None:
-        api_id = yaml_config['apiid']
+    if command_args.test:
+        yaml_file = 'skentest.yaml'
+
+    if 'orgid' in yaml_config and yaml_config['orgid'] is not None:
+        org_id = yaml_config['orgid']
     
-    if command_args.api_id is not None:
-        api_id = command_args.api_id
+    if command_args.org_id is not None:
+        org_id = command_args.org_id
 
-    if not api_id:
-        print('Please specify "apiid" in sken.yaml or use --api_id flag.')
+    if not org_id:
+        if 'apiid' in yaml_config:
+            print('Error: Please rename apiid to orgid.')
+        else:
+            print('Please specify "orgid" in ' + yaml_file + ' or use --org_id flag.')
         exit(-1)
 
     if 'appid' in yaml_config and yaml_config['appid'] is not None:
@@ -105,10 +116,10 @@ def get_app_ids(command_args, yaml_config):
         app_id = command_args.app_id
 
     if not app_id:
-        print('Please specify "apiid" in sken.yaml or use --api_id flag.')
+        print('Please specify "apiid" in ' + yaml_file + ' or use --api_id flag.')
         exit(-1)
 
-    return api_id, app_id
+    return org_id, app_id
 
 def check_language(command_line_params, yaml_config):
     scanners = ''
@@ -137,7 +148,7 @@ def check_language(command_line_params, yaml_config):
     return 'language' in yaml_config or 'language' in command_line_params or (scanners != '' and scanners.find('sast') < 0)
 
 def version():
-    return '0.1.80'
+    return '0.1.83'
 
 def main():
     command_line_params, command_args = parse_command_line_params()
@@ -146,9 +157,9 @@ def main():
 
     build_dir = get_build_dir(command_args)
     succeed, yaml_config = Utils.read_config(build_dir)
-    api_id, app_id = get_app_ids(command_args, yaml_config)
+    org_id, app_id = get_app_ids(command_args, yaml_config)
 
-    awsconfig = Utils.get_aws_config(app_id, api_id)
+    awsconfig = Utils.get_aws_config(app_id, org_id)
     # count files and loc
     files, lines_of_code = Utils.count_file_code(awsconfig, build_dir)
 
@@ -157,7 +168,7 @@ def main():
 
     # initial scan data items
     ScanRunner.run({
-        'apiid': api_id, 
+        'orgid': org_id, 
         'appid': app_id, 
         'buildDir': build_dir,
         'files': files, 
