@@ -29,11 +29,14 @@ class S3Error(Exception):
     pass
 
 class Utils(object):
+	# if test_mode is true, cli connects to the test server
+	test_mode = False
 	sken_output_foler = ''
 	linguist_image = '621002179714.dkr.ecr.us-east-1.amazonaws.com/linguist:latest'
 	cloc_image = '621002179714.dkr.ecr.us-east-1.amazonaws.com/cloc:latest'
 	SKEN_SERVER_BASE_URL = 'https://cli.sken.ai/api/cli/v1'
 	#SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1'
+	SKEN_TEST_SERVER_BASE_URL = 'https://cli-test.sken.ai/api/cli/v1'
 	http = None
 	last_time_docker_login = 0
 	minutes20 = 60*20
@@ -67,6 +70,11 @@ class Utils(object):
 
 		return cls.http
 
+	@classmethod
+	def set_test_mode(cls):
+		cls.test_mode = True
+		cls.SKEN_SERVER_BASE_URL = cls.SKEN_TEST_SERVER_BASE_URL
+
 	@classmethod
 	def assert_docker_alive(cls):
 		try:
@@ -379,19 +387,23 @@ class Utils(object):
 	"""
 	@classmethod
 	def read_config(cls, build_dir):
+		yaml_file = build_dir + 'sken.yaml'
+		if cls.test_mode:
+			yaml_file = build_dir + 'skentest.yaml'
+
 		sken_config = {}
 		succeed = False
-		if os.path.exists(build_dir + 'sken.yaml'):
-			with open(build_dir + 'sken.yaml', 'r') as stream:
+		if os.path.exists(yaml_file):
+			with open(yaml_file, 'r') as stream:
 				try:
 					sken_config = yaml.safe_load(stream)
 					succeed = True
 				except yaml.YAMLError as exc:
-					print('Read '+(build_dir + 'sken.yaml')+' failed, please check the content.')
+					print('Read ' + yaml_file + ' failed, please check the content.')
 					logging.exception(exc)
 					exit(-1)
 		else:
-			print('File not found: %s' % (build_dir + 'sken.yaml'))
+			print('File not found: %s' % yaml_file)
 
 		return succeed, sken_config
 
@@ -429,12 +441,12 @@ class Utils(object):
 		else:
 			variables['maven_repo_path'] = cls.find_m2_location()
 
-		if command_args.var_gradle_repo_path is not None:
-			variables['gradle_repo_path'] = command_args.var_gradle_repo_path
-		elif 'variables' in yaml_config and 'GRADLE_REPO_PATH' in yaml_config['variables'] and yaml_config['variables']['GRADLE_REPO_PATH'] is not None:
-			variables['gradle_repo_path'] = yaml_config['variables']['GRADLE_REPO_PATH']
+		if command_args.var_gradle_cache_path is not None:
+			variables['gradle_cache_path'] = command_args.var_gradle_cache_path
+		elif 'variables' in yaml_config and 'GRADLE_CACHE_PATH' in yaml_config['variables'] and yaml_config['variables']['GRADLE_CACHE_PATH'] is not None:
+			variables['gradle_cache_path'] = yaml_config['variables']['GRADLE_CACHE_PATH']
 		else:
-			variables['gradle_repo_path'] = cls.find_gradle_location()
+			variables['gradle_cache_path'] = cls.find_gradle_location()
 
 		return variables
 
